@@ -5,9 +5,11 @@ from djangorestframework_camel_case.util import camelize
 
 
 class CamelCaseJSONRenderer(api_settings.RENDERER_CLASS):
+    json_underscoreize = api_settings.JSON_UNDERSCOREIZE
+
     def render(self, data, *args, **kwargs):
         return super().render(
-            camelize(data, **api_settings.JSON_UNDERSCOREIZE), *args, **kwargs
+            camelize(data, **self.json_underscoreize), *args, **kwargs
         )
 
 
