@@ -4,7 +4,7 @@ from collections import OrderedDict
 from django.core.files import File
 from django.http import QueryDict
 from django.utils.datastructures import MultiValueDict
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.functional import Promise
 
 from rest_framework.utils.serializer_helpers import ReturnDict
@@ -23,8 +23,9 @@ def underscore_to_camel(match):
 def camelize(data, **options):
     # Handle lazy translated strings.
     ignore_fields = options.get("ignore_fields") or ()
+    ignore_keys = options.get("ignore_keys") or ()
     if isinstance(data, Promise):
-        data = force_text(data)
+        data = force_str(data)
     if isinstance(data, dict):
         if isinstance(data, ReturnDict):
             new_dict = ReturnDict(serializer=data.serializer)
@@ -32,15 +33,20 @@ def camelize(data, **options):
             new_dict = OrderedDict()
         for key, value in data.items():
             if isinstance(key, Promise):
-                key = force_text(key)
+                key = force_str(key)
             if isinstance(key, str) and "_" in key:
                 new_key = re.sub(camelize_re, underscore_to_camel, key)
             else:
                 new_key = key
+
             if key not in ignore_fields and new_key not in ignore_fields:
-                new_dict[new_key] = camelize(value, **options)
+                result = camelize(value, **options)
             else:
-                new_dict[new_key] = value
+                result = value
+            if key in ignore_keys or new_key in ignore_keys:
+                new_dict[key] = result
+            else:
+                new_dict[new_key] = result
         return new_dict
     if is_iterable(data) and not isinstance(data, str):
         return [camelize(item, **options) for item in data]
@@ -51,7 +57,7 @@ def get_underscoreize_re(options):
     if options.get("no_underscore_before_number"):
         pattern = r"([a-z0-9]|[A-Z]?(?=[A-Z](?=[a-z])))([A-Z])"
     else:
-        pattern = r"([a-z0-9]|[A-Z]?(?=[A-Z0-9](?=[a-z0-9]|$)))([A-Z]|(?<=[a-z])[0-9](?=[0-9A-Z]|$)|(?<=[A-Z])[0-9](?=[0-9]|$))"
+        pattern = r"([a-z0-9]|[A-Z]?(?=[A-Z0-9](?=[a-z0-9]|(?<![A-Z])$)))([A-Z]|(?<=[a-z])[0-9](?=[0-9A-Z]|$)|(?<=[A-Z])[0-9](?=[0-9]|$))"
     return re.compile(pattern)
 
 
@@ -69,6 +75,7 @@ def _get_iterable(data):
 
 def underscoreize(data, **options):
     ignore_fields = options.get("ignore_fields") or ()
+    ignore_keys = options.get("ignore_keys") or ()
     if isinstance(data, dict):
         new_dict = {}
         if type(data) == MultiValueDict:
@@ -83,9 +90,13 @@ def underscoreize(data, **options):
                 new_key = key
 
             if key not in ignore_fields and new_key not in ignore_fields:
-                new_dict[new_key] = underscoreize(value, **options)
+                result = underscoreize(value, **options)
             else:
-                new_dict[new_key] = value
+                result = value
+            if key in ignore_keys or new_key in ignore_keys:
+                new_dict[key] = result
+            else:
+                new_dict[new_key] = result
 
         if isinstance(data, QueryDict):
             new_query = QueryDict(mutable=True)
